@@ -29,16 +29,20 @@
 #include <defaults.h>
 
 extern unsigned int selectedJob;
-extern int m_id_upd,c_id_upd,m_id_state,c_id_state;
-extern GtkWidget *buttonPrio, *buttonHold,*buttonMove,*buttonCancel,*buttonCancelAll,*holdLabel,*buttonHoldPrinter,*holdPrinterLabel,*buttonRejectJob;
-extern GtkWidget *holdimage, *printerimage,*rejectjobimage;
-extern GtkWidget *tabs,*statbar;
-extern GdkPixmap *gtklpq_hold,*gtklpq_release,*gtklpq_stop_printer,*gtklpq_start_printer,*gtklpq_reject_job,*gtklpq_accept_job;
-extern GdkBitmap *mgtklpq_hold,*mgtklpq_release,*mgtklpq_stop_printer,*mgtklpq_start_printer,*mgtklpq_reject_job,*mgtklpq_accept_job;
+extern int m_id_upd, c_id_upd, m_id_state, c_id_state;
+extern GtkWidget *buttonPrio, *buttonHold, *buttonMove, *buttonCancel,
+    *buttonCancelAll, *holdLabel, *buttonHoldPrinter, *holdPrinterLabel,
+    *buttonRejectJob;
+extern GtkWidget *holdimage, *printerimage, *rejectjobimage;
+extern GtkWidget *tabs, *statbar;
+extern GdkPixmap *gtklpq_hold, *gtklpq_release, *gtklpq_stop_printer,
+    *gtklpq_start_printer, *gtklpq_reject_job, *gtklpq_accept_job;
+extern GdkBitmap *mgtklpq_hold, *mgtklpq_release, *mgtklpq_stop_printer,
+    *mgtklpq_start_printer, *mgtklpq_reject_job, *mgtklpq_accept_job;
 extern GtkTooltips *tooltips;
 
 extern GtkWidget *dialog;
 
 extern int cancelmode;
 
-#endif /* GTKLPQ_C */
+#endif				/* GTKLPQ_C */
